# Opay Python Library

The OPay Python library provides convenient access to the OPay merchant API from
applications written in the Python language. It includes a pre-defined set of
classes for API resources that initialize themselves dynamically from API
responses which makes the OPay resources easily accessed and enhances 
transaction ease via the OPay API.

